"""500 human emotions — name, emoji, ANSI-256 color, family, intensity (1-5), valence."""

# ANSI 256-color format: \033[38;5;Nm
_C = lambda n: f"\033[38;5;{n}m"

EMOTIONS = {
    # ── JOY (20) ─────────────────────────────────────────────────────────────
    "content":        {"emoji": "😌", "color": _C(222), "name": "content",        "family": "joy", "intensity": 1, "valence": "positive"},
    "pleased":        {"emoji": "🙂", "color": _C(222), "name": "pleased",        "family": "joy", "intensity": 1, "valence": "positive"},
    "lighthearted":   {"emoji": "🌤️", "color": _C(226), "name": "lighthearted",   "family": "joy", "intensity": 1, "valence": "positive"},
    "glad":           {"emoji": "😊", "color": _C(226), "name": "glad",           "family": "joy", "intensity": 1, "valence": "positive"},
    "happy":          {"emoji": "😄", "color": _C(220), "name": "happy",          "family": "joy", "intensity": 2, "valence": "positive"},
    "cheerful":       {"emoji": "😁", "color": _C(220), "name": "cheerful",       "family": "joy", "intensity": 2, "valence": "positive"},
    "merry":          {"emoji": "🎊", "color": _C(220), "name": "merry",          "family": "joy", "intensity": 2, "valence": "positive"},
    "giddy":          {"emoji": "🌀", "color": _C(214), "name": "giddy",          "family": "joy", "intensity": 2, "valence": "positive"},
    "delighted":      {"emoji": "😆", "color": _C(214), "name": "delighted",      "family": "joy", "intensity": 3, "valence": "positive"},
    "gleeful":        {"emoji": "😸", "color": _C(214), "name": "gleeful",        "family": "joy", "intensity": 3, "valence": "positive"},
    "playful":        {"emoji": "🎮", "color": _C(190), "name": "playful",        "family": "joy", "intensity": 3, "valence": "positive"},
    "buoyant":        {"emoji": "🎈", "color": _C(190), "name": "buoyant",        "family": "joy", "intensity": 3, "valence": "positive"},
    "elated":         {"emoji": "🚀", "color": _C(154), "name": "elated",         "family": "joy", "intensity": 4, "valence": "positive"},
    "thrilled":       {"emoji": "⚡", "color": _C(154), "name": "thrilled",       "family": "joy", "intensity": 4, "valence": "positive"},
    "exuberant":      {"emoji": "🎉", "color": _C(118), "name": "exuberant",      "family": "joy", "intensity": 4, "valence": "positive"},
    "radiant":        {"emoji": "✨", "color": _C(118), "name": "radiant",        "family": "joy", "intensity": 4, "valence": "positive"},
    "joyful":         {"emoji": "😄", "color": _C(82),  "name": "joyful",         "family": "joy", "intensity": 5, "valence": "positive"},
    "ecstatic":       {"emoji": "🤩", "color": _C(82),  "name": "ecstatic",       "family": "joy", "intensity": 5, "valence": "positive"},
    "euphoric":       {"emoji": "🌟", "color": _C(46),  "name": "euphoric",       "family": "joy", "intensity": 5, "valence": "positive"},
    "jubilant":       {"emoji": "🏆", "color": _C(46),  "name": "jubilant",       "family": "joy", "intensity": 5, "valence": "positive"},

    # ── SERENITY (20) ────────────────────────────────────────────────────────
    "restful":        {"emoji": "💤", "color": _C(195), "name": "restful",        "family": "serenity", "intensity": 1, "valence": "positive"},
    "quiet":          {"emoji": "🤫", "color": _C(195), "name": "quiet",          "family": "serenity", "intensity": 1, "valence": "positive"},
    "still":          {"emoji": "🌙", "color": _C(189), "name": "still",          "family": "serenity", "intensity": 1, "valence": "positive"},
    "mellow":         {"emoji": "🎵", "color": _C(189), "name": "mellow",         "family": "serenity", "intensity": 1, "valence": "positive"},
    "calm":           {"emoji": "😮‍💨", "color": _C(159), "name": "calm",           "family": "serenity", "intensity": 2, "valence": "positive"},
    "relaxed":        {"emoji": "😴", "color": _C(159), "name": "relaxed",        "family": "serenity", "intensity": 2, "valence": "positive"},
    "comfortable":    {"emoji": "🛋️", "color": _C(123), "name": "comfortable",    "family": "serenity", "intensity": 2, "valence": "positive"},
    "cozy":           {"emoji": "🍵", "color": _C(123), "name": "cozy",           "family": "serenity", "intensity": 2, "valence": "positive"},
    "gentle":         {"emoji": "🌸", "color": _C(87),  "name": "gentle",         "family": "serenity", "intensity": 3, "valence": "positive"},
    "soft":           {"emoji": "🫧", "color": _C(87),  "name": "soft",           "family": "serenity", "intensity": 3, "valence": "positive"},
    "peaceful":       {"emoji": "☮️", "color": _C(51),  "name": "peaceful",       "family": "serenity", "intensity": 3, "valence": "positive"},
    "dreamy":         {"emoji": "💭", "color": _C(51),  "name": "dreamy",         "family": "serenity", "intensity": 3, "valence": "positive"},
    "serene":         {"emoji": "🌊", "color": _C(45),  "name": "serene",         "family": "serenity", "intensity": 4, "valence": "positive"},
    "tranquil":       {"emoji": "🕊️", "color": _C(45),  "name": "tranquil",       "family": "serenity", "intensity": 4, "valence": "positive"},
    "warm":           {"emoji": "🌻", "color": _C(39),  "name": "warm",           "family": "serenity", "intensity": 4, "valence": "positive"},
    "safe":           {"emoji": "🔒", "color": _C(39),  "name": "safe",           "family": "serenity", "intensity": 4, "valence": "positive"},
    "grounded":       {"emoji": "🌿", "color": _C(33),  "name": "grounded",       "family": "serenity", "intensity": 5, "valence": "positive"},
    "centered":       {"emoji": "⚖️", "color": _C(33),  "name": "centered",       "family": "serenity", "intensity": 5, "valence": "positive"},
    "composed":       {"emoji": "🧘", "color": _C(27),  "name": "composed",       "family": "serenity", "intensity": 5, "valence": "positive"},
    "languid":        {"emoji": "🌅", "color": _C(27),  "name": "languid",        "family": "serenity", "intensity": 5, "valence": "positive"},

    # ── GRATITUDE (10) ───────────────────────────────────────────────────────
    "lucky":          {"emoji": "🍀", "color": _C(120), "name": "lucky",          "family": "gratitude", "intensity": 1, "valence": "positive"},
    "thankful":       {"emoji": "💖", "color": _C(120), "name": "thankful",       "family": "gratitude", "intensity": 2, "valence": "positive"},
    "appreciative":   {"emoji": "🤲", "color": _C(119), "name": "appreciative",   "family": "gratitude", "intensity": 2, "valence": "positive"},
    "fortunate":      {"emoji": "⭐", "color": _C(119), "name": "fortunate",      "family": "gratitude", "intensity": 3, "valence": "positive"},
    "grateful":       {"emoji": "🙏", "color": _C(113), "name": "grateful",       "family": "gratitude", "intensity": 3, "valence": "positive"},
    "touched":        {"emoji": "🥹", "color": _C(113), "name": "touched",        "family": "gratitude", "intensity": 4, "valence": "positive"},
    "honored":        {"emoji": "🎗️", "color": _C(107), "name": "honored",        "family": "gratitude", "intensity": 4, "valence": "positive"},
    "blessed":        {"emoji": "🌈", "color": _C(107), "name": "blessed",        "family": "gratitude", "intensity": 4, "valence": "positive"},
    "privileged":     {"emoji": "👑", "color": _C(71),  "name": "privileged",     "family": "gratitude", "intensity": 5, "valence": "positive"},
    "moved":          {"emoji": "💫", "color": _C(71),  "name": "moved",          "family": "gratitude", "intensity": 5, "valence": "positive"},

    # ── LOVE (20) ────────────────────────────────────────────────────────────
    "kindhearted":    {"emoji": "😊", "color": _C(225), "name": "kindhearted",    "family": "love", "intensity": 1, "valence": "positive"},
    "caring":         {"emoji": "💗", "color": _C(225), "name": "caring",         "family": "love", "intensity": 1, "valence": "positive"},
    "generous":       {"emoji": "🎁", "color": _C(219), "name": "generous",       "family": "love", "intensity": 1, "valence": "positive"},
    "sympathetic":    {"emoji": "🤗", "color": _C(219), "name": "sympathetic",    "family": "love", "intensity": 1, "valence": "positive"},
    "empathetic":     {"emoji": "🫂", "color": _C(213), "name": "empathetic",     "family": "love", "intensity": 2, "valence": "positive"},
    "compassionate":  {"emoji": "💙", "color": _C(213), "name": "compassionate",  "family": "love", "intensity": 2, "valence": "positive"},
    "affectionate":   {"emoji": "🥰", "color": _C(207), "name": "affectionate",   "family": "love", "intensity": 2, "valence": "positive"},
    "nurturing":      {"emoji": "🤱", "color": _C(207), "name": "nurturing",      "family": "love", "intensity": 2, "valence": "positive"},
    "connected":      {"emoji": "🤝", "color": _C(201), "name": "connected",      "family": "love", "intensity": 3, "valence": "positive"},
    "bonded":         {"emoji": "🔗", "color": _C(201), "name": "bonded",         "family": "love", "intensity": 3, "valence": "positive"},
    "protective":     {"emoji": "🛡️", "color": _C(200), "name": "protective",     "family": "love", "intensity": 3, "valence": "positive"},
    "devoted":        {"emoji": "💕", "color": _C(200), "name": "devoted",        "family": "love", "intensity": 3, "valence": "positive"},
    "loving":         {"emoji": "❤️", "color": _C(198), "name": "loving",         "family": "love", "intensity": 4, "valence": "positive"},
    "intimate":       {"emoji": "🫶", "color": _C(198), "name": "intimate",       "family": "love", "intensity": 4, "valence": "positive"},
    "adoring":        {"emoji": "😍", "color": _C(197), "name": "adoring",        "family": "love", "intensity": 4, "valence": "positive"},
    "romantic":       {"emoji": "🌹", "color": _C(197), "name": "romantic",       "family": "love", "intensity": 4, "valence": "positive"},
    "passionate":     {"emoji": "🔥", "color": _C(196), "name": "passionate",     "family": "love", "intensity": 5, "valence": "positive"},
    "infatuated":     {"emoji": "💘", "color": _C(196), "name": "infatuated",     "family": "love", "intensity": 5, "valence": "positive"},
    "lovestruck":     {"emoji": "💞", "color": _C(204), "name": "lovestruck",     "family": "love", "intensity": 5, "valence": "positive"},
    "smitten":        {"emoji": "💓", "color": _C(204), "name": "smitten",        "family": "love", "intensity": 5, "valence": "positive"},

    # ── LONGING (10) ─────────────────────────────────────────────────────────
    "missing":        {"emoji": "🫙", "color": _C(183), "name": "missing",        "family": "longing", "intensity": 1, "valence": "mixed"},
    "reminiscent":    {"emoji": "🗓️", "color": _C(183), "name": "reminiscent",    "family": "longing", "intensity": 2, "valence": "mixed"},
    "sentimental":    {"emoji": "📷", "color": _C(177), "name": "sentimental",    "family": "longing", "intensity": 2, "valence": "mixed"},
    "nostalgic":      {"emoji": "🥹", "color": _C(177), "name": "nostalgic",      "family": "longing", "intensity": 3, "valence": "mixed"},
    "wistful":        {"emoji": "🌧️", "color": _C(171), "name": "wistful",        "family": "longing", "intensity": 3, "valence": "mixed"},
    "bittersweet":    {"emoji": "🍂", "color": _C(171), "name": "bittersweet",    "family": "longing", "intensity": 3, "valence": "mixed"},
    "pining":         {"emoji": "💌", "color": _C(165), "name": "pining",         "family": "longing", "intensity": 4, "valence": "negative"},
    "homesick":       {"emoji": "🏠", "color": _C(165), "name": "homesick",       "family": "longing", "intensity": 4, "valence": "negative"},
    "yearning":       {"emoji": "🌠", "color": _C(129), "name": "yearning",       "family": "longing", "intensity": 5, "valence": "negative"},
    "longing":        {"emoji": "💭", "color": _C(129), "name": "longing",        "family": "longing", "intensity": 5, "valence": "negative"},

    # ── SADNESS (20) ─────────────────────────────────────────────────────────
    "downcast":       {"emoji": "😓", "color": _C(153), "name": "downcast",       "family": "sadness", "intensity": 1, "valence": "negative"},
    "unhappy":        {"emoji": "😟", "color": _C(153), "name": "unhappy",        "family": "sadness", "intensity": 1, "valence": "negative"},
    "gloomy":         {"emoji": "🌩️", "color": _C(117), "name": "gloomy",         "family": "sadness", "intensity": 1, "valence": "negative"},
    "dejected":       {"emoji": "😔", "color": _C(117), "name": "dejected",       "family": "sadness", "intensity": 1, "valence": "negative"},
    "sad":            {"emoji": "😢", "color": _C(75),  "name": "sad",            "family": "sadness", "intensity": 2, "valence": "negative"},
    "sorrowful":      {"emoji": "😞", "color": _C(75),  "name": "sorrowful",      "family": "sadness", "intensity": 2, "valence": "negative"},
    "melancholic":    {"emoji": "🌧️", "color": _C(69),  "name": "melancholic",    "family": "sadness", "intensity": 2, "valence": "negative"},
    "forlorn":        {"emoji": "🥀", "color": _C(69),  "name": "forlorn",        "family": "sadness", "intensity": 2, "valence": "negative"},
    "dismal":         {"emoji": "⛈️", "color": _C(63),  "name": "dismal",         "family": "sadness", "intensity": 3, "valence": "negative"},
    "wretched":       {"emoji": "😿", "color": _C(63),  "name": "wretched",       "family": "sadness", "intensity": 3, "valence": "negative"},
    "miserable":      {"emoji": "😩", "color": _C(57),  "name": "miserable",      "family": "sadness", "intensity": 3, "valence": "negative"},
    "mournful":       {"emoji": "🪦", "color": _C(57),  "name": "mournful",       "family": "sadness", "intensity": 3, "valence": "negative"},
    "heartbroken":    {"emoji": "💔", "color": _C(27),  "name": "heartbroken",    "family": "sadness", "intensity": 4, "valence": "negative"},
    "desolate":       {"emoji": "🏚️", "color": _C(27),  "name": "desolate",       "family": "sadness", "intensity": 4, "valence": "negative"},
    "bereaved":       {"emoji": "🕯️", "color": _C(21),  "name": "bereaved",       "family": "sadness", "intensity": 4, "valence": "negative"},
    "lamenting":      {"emoji": "😫", "color": _C(21),  "name": "lamenting",      "family": "sadness", "intensity": 4, "valence": "negative"},
    "devastated":     {"emoji": "😭", "color": _C(18),  "name": "devastated",     "family": "sadness", "intensity": 5, "valence": "negative"},
    "despairing":     {"emoji": "🌑", "color": _C(18),  "name": "despairing",     "family": "sadness", "intensity": 5, "valence": "negative"},
    "inconsolable":   {"emoji": "💔", "color": _C(17),  "name": "inconsolable",   "family": "sadness", "intensity": 5, "valence": "negative"},
    "crushed":        {"emoji": "🫀", "color": _C(17),  "name": "crushed",        "family": "sadness", "intensity": 5, "valence": "negative"},

    # ── DISAPPOINTMENT (10) ──────────────────────────────────────────────────
    "deflated":       {"emoji": "🎈", "color": _C(246), "name": "deflated",       "family": "disappointment", "intensity": 1, "valence": "negative"},
    "disappointed":   {"emoji": "😞", "color": _C(246), "name": "disappointed",   "family": "disappointment", "intensity": 2, "valence": "negative"},
    "let_down":       {"emoji": "😔", "color": _C(243), "name": "let_down",       "family": "disappointment", "intensity": 2, "valence": "negative"},
    "crestfallen":    {"emoji": "😕", "color": _C(243), "name": "crestfallen",    "family": "disappointment", "intensity": 3, "valence": "negative"},
    "disillusioned":  {"emoji": "😒", "color": _C(240), "name": "disillusioned",  "family": "disappointment", "intensity": 3, "valence": "negative"},
    "regretful":      {"emoji": "😣", "color": _C(240), "name": "regretful",      "family": "disappointment", "intensity": 3, "valence": "negative"},
    "remorseful":     {"emoji": "😢", "color": _C(238), "name": "remorseful",     "family": "disappointment", "intensity": 4, "valence": "negative"},
    "disheartened":   {"emoji": "💔", "color": _C(238), "name": "disheartened",   "family": "disappointment", "intensity": 4, "valence": "negative"},
    "defeated":       {"emoji": "🏳️", "color": _C(236), "name": "defeated",       "family": "disappointment", "intensity": 5, "valence": "negative"},
    "resigned":       {"emoji": "😑", "color": _C(236), "name": "resigned",       "family": "disappointment", "intensity": 5, "valence": "negative"},

    # ── LONELINESS (10) ──────────────────────────────────────────────────────
    "overlooked":     {"emoji": "👤", "color": _C(61),  "name": "overlooked",     "family": "loneliness", "intensity": 1, "valence": "negative"},
    "excluded":       {"emoji": "🚫", "color": _C(61),  "name": "excluded",       "family": "loneliness", "intensity": 2, "valence": "negative"},
    "misunderstood":  {"emoji": "🤷", "color": _C(60),  "name": "misunderstood",  "family": "loneliness", "intensity": 2, "valence": "negative"},
    "neglected":      {"emoji": "🕳️", "color": _C(60),  "name": "neglected",      "family": "loneliness", "intensity": 3, "valence": "negative"},
    "lonely":         {"emoji": "🥺", "color": _C(55),  "name": "lonely",         "family": "loneliness", "intensity": 3, "valence": "negative"},
    "invisible":      {"emoji": "👻", "color": _C(55),  "name": "invisible",      "family": "loneliness", "intensity": 3, "valence": "negative"},
    "unwanted":       {"emoji": "❌", "color": _C(54),  "name": "unwanted",       "family": "loneliness", "intensity": 4, "valence": "negative"},
    "rejected":       {"emoji": "↩️", "color": _C(54),  "name": "rejected",       "family": "loneliness", "intensity": 4, "valence": "negative"},
    "abandoned":      {"emoji": "🚪", "color": _C(53),  "name": "abandoned",      "family": "loneliness", "intensity": 5, "valence": "negative"},
    "alienated":      {"emoji": "🌑", "color": _C(53),  "name": "alienated",      "family": "loneliness", "intensity": 5, "valence": "negative"},

    # ── FEAR (10) ────────────────────────────────────────────────────────────
    "wary":           {"emoji": "👀", "color": _C(209), "name": "wary",           "family": "fear", "intensity": 1, "valence": "negative"},
    "threatened":     {"emoji": "⚠️", "color": _C(209), "name": "threatened",     "family": "fear", "intensity": 2, "valence": "negative"},
    "fearful":        {"emoji": "😨", "color": _C(203), "name": "fearful",        "family": "fear", "intensity": 2, "valence": "negative"},
    "scared":         {"emoji": "😱", "color": _C(203), "name": "scared",         "family": "fear", "intensity": 3, "valence": "negative"},
    "dreading":       {"emoji": "😬", "color": _C(197), "name": "dreading",       "family": "fear", "intensity": 3, "valence": "negative"},
    "phobic":         {"emoji": "🕷️", "color": _C(197), "name": "phobic",         "family": "fear", "intensity": 4, "valence": "negative"},
    "paranoid":       {"emoji": "👁️", "color": _C(196), "name": "paranoid",       "family": "fear", "intensity": 4, "valence": "negative"},
    "petrified":      {"emoji": "🧊", "color": _C(196), "name": "petrified",      "family": "fear", "intensity": 5, "valence": "negative"},
    "horrified":      {"emoji": "😱", "color": _C(160), "name": "horrified",      "family": "fear", "intensity": 5, "valence": "negative"},
    "panicked":       {"emoji": "🆘", "color": _C(160), "name": "panicked",       "family": "fear", "intensity": 5, "valence": "negative"},

    # ── ANXIETY (10) ─────────────────────────────────────────────────────────
    "uneasy":         {"emoji": "😕", "color": _C(215), "name": "uneasy",         "family": "anxiety", "intensity": 1, "valence": "negative"},
    "nervous":        {"emoji": "😰", "color": _C(215), "name": "nervous",        "family": "anxiety", "intensity": 2, "valence": "negative"},
    "worried":        {"emoji": "😟", "color": _C(209), "name": "worried",        "family": "anxiety", "intensity": 2, "valence": "negative"},
    "apprehensive":   {"emoji": "😦", "color": _C(209), "name": "apprehensive",   "family": "anxiety", "intensity": 3, "valence": "negative"},
    "tense":          {"emoji": "😤", "color": _C(208), "name": "tense",          "family": "anxiety", "intensity": 3, "valence": "negative"},
    "stressed":       {"emoji": "🤯", "color": _C(208), "name": "stressed",       "family": "anxiety", "intensity": 3, "valence": "negative"},
    "jumpy":          {"emoji": "🐱", "color": _C(202), "name": "jumpy",          "family": "anxiety", "intensity": 4, "valence": "negative"},
    "on_edge":        {"emoji": "⚡", "color": _C(202), "name": "on_edge",        "family": "anxiety", "intensity": 4, "valence": "negative"},
    "anxious":        {"emoji": "😰", "color": _C(166), "name": "anxious",        "family": "anxiety", "intensity": 5, "valence": "negative"},
    "restless":       {"emoji": "🌀", "color": _C(166), "name": "restless",       "family": "anxiety", "intensity": 5, "valence": "negative"},

    # ── VULNERABILITY (10) ───────────────────────────────────────────────────
    "hesitant":       {"emoji": "⏸️", "color": _C(224), "name": "hesitant",       "family": "vulnerability", "intensity": 1, "valence": "negative"},
    "timid":          {"emoji": "🐭", "color": _C(224), "name": "timid",          "family": "vulnerability", "intensity": 1, "valence": "negative"},
    "cautious":       {"emoji": "🚧", "color": _C(218), "name": "cautious",       "family": "vulnerability", "intensity": 2, "valence": "neutral"},
    "doubtful":       {"emoji": "🤔", "color": _C(218), "name": "doubtful",       "family": "vulnerability", "intensity": 2, "valence": "negative"},
    "uncertain":      {"emoji": "❓", "color": _C(212), "name": "uncertain",      "family": "vulnerability", "intensity": 3, "valence": "negative"},
    "insecure":       {"emoji": "😟", "color": _C(212), "name": "insecure",       "family": "vulnerability", "intensity": 3, "valence": "negative"},
    "exposed":        {"emoji": "🫙", "color": _C(206), "name": "exposed",        "family": "vulnerability", "intensity": 4, "valence": "negative"},
    "fragile":        {"emoji": "🪞", "color": _C(206), "name": "fragile",        "family": "vulnerability", "intensity": 4, "valence": "negative"},
    "vulnerable":     {"emoji": "🫧", "color": _C(181), "name": "vulnerable",     "family": "vulnerability", "intensity": 5, "valence": "negative"},
    "raw":            {"emoji": "💗", "color": _C(181), "name": "raw",            "family": "vulnerability", "intensity": 5, "valence": "negative"},

    # ── ANGER (10) ───────────────────────────────────────────────────────────
    "irritable":      {"emoji": "😒", "color": _C(210), "name": "irritable",      "family": "anger", "intensity": 1, "valence": "negative"},
    "angry":          {"emoji": "😠", "color": _C(204), "name": "angry",          "family": "anger", "intensity": 2, "valence": "negative"},
    "irate":          {"emoji": "😾", "color": _C(204), "name": "irate",          "family": "anger", "intensity": 2, "valence": "negative"},
    "outraged":       {"emoji": "😤", "color": _C(197), "name": "outraged",       "family": "anger", "intensity": 3, "valence": "negative"},
    "incensed":       {"emoji": "🔥", "color": _C(197), "name": "incensed",       "family": "anger", "intensity": 3, "valence": "negative"},
    "furious":        {"emoji": "🤬", "color": _C(196), "name": "furious",        "family": "anger", "intensity": 4, "valence": "negative"},
    "livid":          {"emoji": "😡", "color": _C(196), "name": "livid",          "family": "anger", "intensity": 4, "valence": "negative"},
    "enraged":        {"emoji": "💢", "color": _C(160), "name": "enraged",        "family": "anger", "intensity": 5, "valence": "negative"},
    "wrathful":       {"emoji": "⚡", "color": _C(160), "name": "wrathful",       "family": "anger", "intensity": 5, "valence": "negative"},
    "seething":       {"emoji": "🌋", "color": _C(124), "name": "seething",       "family": "anger", "intensity": 5, "valence": "negative"},

    # ── IRRITATION (10) ──────────────────────────────────────────────────────
    "cranky":         {"emoji": "😾", "color": _C(216), "name": "cranky",         "family": "irritation", "intensity": 1, "valence": "negative"},
    "grumpy":         {"emoji": "😒", "color": _C(216), "name": "grumpy",         "family": "irritation", "intensity": 1, "valence": "negative"},
    "annoyed":        {"emoji": "😤", "color": _C(210), "name": "annoyed",        "family": "irritation", "intensity": 2, "valence": "negative"},
    "flustered":      {"emoji": "😅", "color": _C(210), "name": "flustered",      "family": "irritation", "intensity": 2, "valence": "negative"},
    "irritated":      {"emoji": "😒", "color": _C(172), "name": "irritated",      "family": "irritation", "intensity": 3, "valence": "negative"},
    "vexed":          {"emoji": "😫", "color": _C(172), "name": "vexed",          "family": "irritation", "intensity": 3, "valence": "negative"},
    "agitated":       {"emoji": "😤", "color": _C(166), "name": "agitated",       "family": "irritation", "intensity": 4, "valence": "negative"},
    "impatient":      {"emoji": "⏰", "color": _C(166), "name": "impatient",      "family": "irritation", "intensity": 4, "valence": "negative"},
    "frustrated":     {"emoji": "😣", "color": _C(130), "name": "frustrated",     "family": "irritation", "intensity": 5, "valence": "negative"},
    "exasperated":    {"emoji": "😩", "color": _C(130), "name": "exasperated",    "family": "irritation", "intensity": 5, "valence": "negative"},

    # ── RESENTMENT (10) ──────────────────────────────────────────────────────
    "offended":       {"emoji": "😤", "color": _C(173), "name": "offended",       "family": "resentment", "intensity": 1, "valence": "negative"},
    "indignant":      {"emoji": "😠", "color": _C(173), "name": "indignant",      "family": "resentment", "intensity": 2, "valence": "negative"},
    "bitter":         {"emoji": "🍋", "color": _C(136), "name": "bitter",         "family": "resentment", "intensity": 2, "valence": "negative"},
    "resentful":      {"emoji": "😒", "color": _C(136), "name": "resentful",      "family": "resentment", "intensity": 3, "valence": "negative"},
    "disdainful":     {"emoji": "😏", "color": _C(130), "name": "disdainful",     "family": "resentment", "intensity": 3, "valence": "negative"},
    "scornful":       {"emoji": "😤", "color": _C(130), "name": "scornful",       "family": "resentment", "intensity": 4, "valence": "negative"},
    "contemptuous":   {"emoji": "🙄", "color": _C(94),  "name": "contemptuous",   "family": "resentment", "intensity": 4, "valence": "negative"},
    "hostile":        {"emoji": "🗡️", "color": _C(94),  "name": "hostile",        "family": "resentment", "intensity": 4, "valence": "negative"},
    "spiteful":       {"emoji": "🐍", "color": _C(88),  "name": "spiteful",       "family": "resentment", "intensity": 5, "valence": "negative"},
    "vindictive":     {"emoji": "⚔️", "color": _C(88),  "name": "vindictive",     "family": "resentment", "intensity": 5, "valence": "negative"},

    # ── JEALOUSY (10) ────────────────────────────────────────────────────────
    "competitive":    {"emoji": "🏁", "color": _C(107), "name": "competitive",    "family": "jealousy", "intensity": 1, "valence": "neutral"},
    "envious":        {"emoji": "🟢", "color": _C(107), "name": "envious",        "family": "jealousy", "intensity": 2, "valence": "negative"},
    "covetous":       {"emoji": "👁️", "color": _C(70),  "name": "covetous",       "family": "jealousy", "intensity": 2, "valence": "negative"},
    "territorial":    {"emoji": "🦁", "color": _C(70),  "name": "territorial",    "family": "jealousy", "intensity": 3, "valence": "negative"},
    "jealous":        {"emoji": "😒", "color": _C(64),  "name": "jealous",        "family": "jealousy", "intensity": 3, "valence": "negative"},
    "overshadowed":   {"emoji": "🌑", "color": _C(64),  "name": "overshadowed",   "family": "jealousy", "intensity": 3, "valence": "negative"},
    "slighted":       {"emoji": "📉", "color": _C(58),  "name": "slighted",       "family": "jealousy", "intensity": 4, "valence": "negative"},
    "possessive":     {"emoji": "🔐", "color": _C(58),  "name": "possessive",     "family": "jealousy", "intensity": 4, "valence": "negative"},
    "inferior_feeling": {"emoji": "⬇️", "color": _C(22), "name": "inferior_feeling", "family": "jealousy", "intensity": 5, "valence": "negative"},
    "overlooked_deep": {"emoji": "👤", "color": _C(22), "name": "overlooked_deep", "family": "jealousy", "intensity": 5, "valence": "negative"},

    # ── DISGUST (10) ─────────────────────────────────────────────────────────
    "distasteful":    {"emoji": "😖", "color": _C(143), "name": "distasteful",    "family": "disgust", "intensity": 1, "valence": "negative"},
    "uncomfortable_d": {"emoji": "😣", "color": _C(143), "name": "uncomfortable_d", "family": "disgust", "intensity": 2, "valence": "negative"},
    "disgusted":      {"emoji": "🤢", "color": _C(100), "name": "disgusted",      "family": "disgust", "intensity": 2, "valence": "negative"},
    "repelled":       {"emoji": "↩️", "color": _C(100), "name": "repelled",       "family": "disgust", "intensity": 3, "valence": "negative"},
    "nauseated":      {"emoji": "🤢", "color": _C(58),  "name": "nauseated",      "family": "disgust", "intensity": 3, "valence": "negative"},
    "aversion_feeling": {"emoji": "🚫", "color": _C(58), "name": "aversion_feeling", "family": "disgust", "intensity": 3, "valence": "negative"},
    "repulsed":       {"emoji": "😷", "color": _C(94),  "name": "repulsed",       "family": "disgust", "intensity": 4, "valence": "negative"},
    "affronted":      {"emoji": "😤", "color": _C(94),  "name": "affronted",      "family": "disgust", "intensity": 4, "valence": "negative"},
    "revolted":       {"emoji": "🤮", "color": _C(88),  "name": "revolted",       "family": "disgust", "intensity": 5, "valence": "negative"},
    "appalled":       {"emoji": "😱", "color": _C(88),  "name": "appalled",       "family": "disgust", "intensity": 5, "valence": "negative"},

    # ── SURPRISE (10) ────────────────────────────────────────────────────────
    "startled":       {"emoji": "😮", "color": _C(159), "name": "startled",       "family": "surprise", "intensity": 1, "valence": "neutral"},
    "surprised":      {"emoji": "😲", "color": _C(87),  "name": "surprised",      "family": "surprise", "intensity": 2, "valence": "neutral"},
    "shocked":        {"emoji": "😳", "color": _C(87),  "name": "shocked",        "family": "surprise", "intensity": 2, "valence": "neutral"},
    "amazed":         {"emoji": "🤩", "color": _C(51),  "name": "amazed",         "family": "surprise", "intensity": 3, "valence": "positive"},
    "astonished":     {"emoji": "😮", "color": _C(51),  "name": "astonished",     "family": "surprise", "intensity": 3, "valence": "neutral"},
    "astounded":      {"emoji": "😯", "color": _C(45),  "name": "astounded",      "family": "surprise", "intensity": 4, "valence": "neutral"},
    "dumbfounded":    {"emoji": "🫢", "color": _C(45),  "name": "dumbfounded",    "family": "surprise", "intensity": 4, "valence": "neutral"},
    "flabbergasted":  {"emoji": "🙀", "color": _C(39),  "name": "flabbergasted",  "family": "surprise", "intensity": 5, "valence": "neutral"},
    "speechless":     {"emoji": "🤐", "color": _C(39),  "name": "speechless",     "family": "surprise", "intensity": 5, "valence": "neutral"},
    "stunned":        {"emoji": "💫", "color": _C(33),  "name": "stunned",        "family": "surprise", "intensity": 5, "valence": "neutral"},

    # ── WONDER (10) ──────────────────────────────────────────────────────────
    "curious":        {"emoji": "🧐", "color": _C(189), "name": "curious",        "family": "wonder", "intensity": 1, "valence": "positive"},
    "intrigued":      {"emoji": "🔍", "color": _C(147), "name": "intrigued",      "family": "wonder", "intensity": 2, "valence": "positive"},
    "fascinated":     {"emoji": "🤩", "color": _C(141), "name": "fascinated",     "family": "wonder", "intensity": 3, "valence": "positive"},
    "captivated":     {"emoji": "😍", "color": _C(135), "name": "captivated",     "family": "wonder", "intensity": 3, "valence": "positive"},
    "enchanted":      {"emoji": "✨", "color": _C(129), "name": "enchanted",      "family": "wonder", "intensity": 4, "valence": "positive"},
    "mesmerized":     {"emoji": "🌀", "color": _C(129), "name": "mesmerized",     "family": "wonder", "intensity": 4, "valence": "positive"},
    "spellbound":     {"emoji": "🪄", "color": _C(105), "name": "spellbound",     "family": "wonder", "intensity": 4, "valence": "positive"},
    "enthralled":     {"emoji": "🎭", "color": _C(105), "name": "enthralled",     "family": "wonder", "intensity": 5, "valence": "positive"},
    "awestruck":      {"emoji": "🌟", "color": _C(99),  "name": "awestruck",      "family": "wonder", "intensity": 5, "valence": "positive"},
    "wondering":      {"emoji": "🌌", "color": _C(99),  "name": "wondering",      "family": "wonder", "intensity": 5, "valence": "positive"},

    # ── ANTICIPATION (10) ────────────────────────────────────────────────────
    "expectant":      {"emoji": "👀", "color": _C(229), "name": "expectant",      "family": "anticipation", "intensity": 1, "valence": "positive"},
    "hopeful":        {"emoji": "🌱", "color": _C(229), "name": "hopeful",        "family": "anticipation", "intensity": 2, "valence": "positive"},
    "eager":          {"emoji": "🐕", "color": _C(226), "name": "eager",          "family": "anticipation", "intensity": 2, "valence": "positive"},
    "anticipating":   {"emoji": "⏳", "color": _C(220), "name": "anticipating",   "family": "anticipation", "intensity": 3, "valence": "positive"},
    "enthusiastic":   {"emoji": "🚀", "color": _C(220), "name": "enthusiastic",   "family": "anticipation", "intensity": 3, "valence": "positive"},
    "pumped":         {"emoji": "💪", "color": _C(214), "name": "pumped",         "family": "anticipation", "intensity": 4, "valence": "positive"},
    "zealous":        {"emoji": "⚡", "color": _C(214), "name": "zealous",        "family": "anticipation", "intensity": 4, "valence": "positive"},
    "excited":        {"emoji": "🎉", "color": _C(208), "name": "excited",        "family": "anticipation", "intensity": 4, "valence": "positive"},
    "fired_up":       {"emoji": "🔥", "color": _C(202), "name": "fired_up",       "family": "anticipation", "intensity": 5, "valence": "positive"},
    "buzzing":        {"emoji": "🐝", "color": _C(202), "name": "buzzing",        "family": "anticipation", "intensity": 5, "valence": "positive"},

    # ── CONFIDENCE (10) ──────────────────────────────────────────────────────
    "self_assured":   {"emoji": "😌", "color": _C(153), "name": "self_assured",   "family": "confidence", "intensity": 1, "valence": "positive"},
    "assertive":      {"emoji": "✊", "color": _C(117), "name": "assertive",      "family": "confidence", "intensity": 2, "valence": "positive"},
    "bold":           {"emoji": "💪", "color": _C(75),  "name": "bold",           "family": "confidence", "intensity": 2, "valence": "positive"},
    "confident":      {"emoji": "😎", "color": _C(75),  "name": "confident",      "family": "confidence", "intensity": 3, "valence": "positive"},
    "proud":          {"emoji": "🦁", "color": _C(33),  "name": "proud",          "family": "confidence", "intensity": 3, "valence": "positive"},
    "brave":          {"emoji": "🦸", "color": _C(33),  "name": "brave",          "family": "confidence", "intensity": 4, "valence": "positive"},
    "courageous":     {"emoji": "⚔️", "color": _C(27),  "name": "courageous",     "family": "confidence", "intensity": 4, "valence": "positive"},
    "daring":         {"emoji": "🪂", "color": _C(27),  "name": "daring",         "family": "confidence", "intensity": 5, "valence": "positive"},
    "fearless":       {"emoji": "🔱", "color": _C(21),  "name": "fearless",       "family": "confidence", "intensity": 5, "valence": "positive"},
    "invincible":     {"emoji": "🏆", "color": _C(21),  "name": "invincible",     "family": "confidence", "intensity": 5, "valence": "positive"},

    # ── AMBITION (10) ────────────────────────────────────────────────────────
    "focused":        {"emoji": "🎯", "color": _C(229), "name": "focused",        "family": "ambition", "intensity": 1, "valence": "positive"},
    "disciplined":    {"emoji": "📐", "color": _C(221), "name": "disciplined",    "family": "ambition", "intensity": 2, "valence": "positive"},
    "committed":      {"emoji": "🔒", "color": _C(214), "name": "committed",      "family": "ambition", "intensity": 2, "valence": "positive"},
    "motivated":      {"emoji": "🔥", "color": _C(208), "name": "motivated",      "family": "ambition", "intensity": 3, "valence": "positive"},
    "driven":         {"emoji": "💨", "color": _C(208), "name": "driven",         "family": "ambition", "intensity": 3, "valence": "positive"},
    "determined":     {"emoji": "🎯", "color": _C(202), "name": "determined",     "family": "ambition", "intensity": 4, "valence": "positive"},
    "dedicated":      {"emoji": "💎", "color": _C(202), "name": "dedicated",      "family": "ambition", "intensity": 4, "valence": "positive"},
    "persistent":     {"emoji": "🌊", "color": _C(196), "name": "persistent",     "family": "ambition", "intensity": 4, "valence": "positive"},
    "ambitious":      {"emoji": "🚀", "color": _C(196), "name": "ambitious",      "family": "ambition", "intensity": 5, "valence": "positive"},
    "relentless":     {"emoji": "⚡", "color": _C(160), "name": "relentless",     "family": "ambition", "intensity": 5, "valence": "positive"},

    # ── ACCOMPLISHMENT (10) ──────────────────────────────────────────────────
    "capable":        {"emoji": "💪", "color": _C(229), "name": "capable",        "family": "accomplishment", "intensity": 1, "valence": "positive"},
    "competent":      {"emoji": "🔧", "color": _C(221), "name": "competent",      "family": "accomplishment", "intensity": 2, "valence": "positive"},
    "satisfied":      {"emoji": "😌", "color": _C(221), "name": "satisfied",      "family": "accomplishment", "intensity": 2, "valence": "positive"},
    "gratified":      {"emoji": "😊", "color": _C(185), "name": "gratified",      "family": "accomplishment", "intensity": 3, "valence": "positive"},
    "fulfilled":      {"emoji": "💫", "color": _C(185), "name": "fulfilled",      "family": "accomplishment", "intensity": 3, "valence": "positive"},
    "accomplished":   {"emoji": "🏅", "color": _C(178), "name": "accomplished",   "family": "accomplishment", "intensity": 4, "valence": "positive"},
    "skilled":        {"emoji": "🎨", "color": _C(178), "name": "skilled",        "family": "accomplishment", "intensity": 4, "valence": "positive"},
    "successful":     {"emoji": "🌟", "color": _C(172), "name": "successful",     "family": "accomplishment", "intensity": 4, "valence": "positive"},
    "masterful":      {"emoji": "👑", "color": _C(136), "name": "masterful",      "family": "accomplishment", "intensity": 5, "valence": "positive"},
    "triumphant":     {"emoji": "🥇", "color": _C(136), "name": "triumphant",     "family": "accomplishment", "intensity": 5, "valence": "positive"},

    # ── HUMILITY (10) ────────────────────────────────────────────────────────
    "unassuming":     {"emoji": "🌱", "color": _C(253), "name": "unassuming",     "family": "humility", "intensity": 1, "valence": "positive"},
    "modest":         {"emoji": "🌿", "color": _C(250), "name": "modest",         "family": "humility", "intensity": 1, "valence": "positive"},
    "reserved":       {"emoji": "🚪", "color": _C(248), "name": "reserved",       "family": "humility", "intensity": 2, "valence": "neutral"},
    "bashful":        {"emoji": "🙈", "color": _C(248), "name": "bashful",        "family": "humility", "intensity": 2, "valence": "neutral"},
    "shy":            {"emoji": "😳", "color": _C(245), "name": "shy",            "family": "humility", "intensity": 3, "valence": "neutral"},
    "self_conscious": {"emoji": "😶", "color": _C(245), "name": "self_conscious", "family": "humility", "intensity": 3, "valence": "neutral"},
    "introverted":    {"emoji": "🔋", "color": _C(242), "name": "introverted",    "family": "humility", "intensity": 3, "valence": "neutral"},
    "meek":           {"emoji": "🕊️", "color": _C(242), "name": "meek",           "family": "humility", "intensity": 4, "valence": "neutral"},
    "humble":         {"emoji": "🙏", "color": _C(238), "name": "humble",         "family": "humility", "intensity": 4, "valence": "positive"},
    "diffident":      {"emoji": "🐢", "color": _C(238), "name": "diffident",      "family": "humility", "intensity": 5, "valence": "neutral"},

    # ── INTELLECTUAL (10) ────────────────────────────────────────────────────
    "systematic":     {"emoji": "📊", "color": _C(153), "name": "systematic",     "family": "intellectual", "intensity": 1, "valence": "neutral"},
    "methodical":     {"emoji": "📋", "color": _C(117), "name": "methodical",     "family": "intellectual", "intensity": 2, "valence": "neutral"},
    "logical":        {"emoji": "🧠", "color": _C(81),  "name": "logical",        "family": "intellectual", "intensity": 2, "valence": "neutral"},
    "analytical":     {"emoji": "🔬", "color": _C(75),  "name": "analytical",     "family": "intellectual", "intensity": 3, "valence": "neutral"},
    "precise":        {"emoji": "🎯", "color": _C(39),  "name": "precise",        "family": "intellectual", "intensity": 3, "valence": "neutral"},
    "strategic":      {"emoji": "♟️", "color": _C(39),  "name": "strategic",      "family": "intellectual", "intensity": 4, "valence": "neutral"},
    "thorough":       {"emoji": "📚", "color": _C(33),  "name": "thorough",       "family": "intellectual", "intensity": 4, "valence": "neutral"},
    "discerning":     {"emoji": "🔎", "color": _C(33),  "name": "discerning",     "family": "intellectual", "intensity": 4, "valence": "neutral"},
    "perfectionist":  {"emoji": "🔍", "color": _C(27),  "name": "perfectionist",  "family": "intellectual", "intensity": 5, "valence": "neutral"},
    "philosophical":  {"emoji": "💭", "color": _C(27),  "name": "philosophical",  "family": "intellectual", "intensity": 5, "valence": "neutral"},

    # ── CREATIVE (10) ────────────────────────────────────────────────────────
    "whimsical":      {"emoji": "🦋", "color": _C(219), "name": "whimsical",      "family": "creative", "intensity": 1, "valence": "positive"},
    "imaginative":    {"emoji": "🌈", "color": _C(213), "name": "imaginative",    "family": "creative", "intensity": 2, "valence": "positive"},
    "spontaneous":    {"emoji": "🌀", "color": _C(177), "name": "spontaneous",    "family": "creative", "intensity": 2, "valence": "positive"},
    "artistic":       {"emoji": "🖌️", "color": _C(141), "name": "artistic",       "family": "creative", "intensity": 3, "valence": "positive"},
    "expressive":     {"emoji": "🎭", "color": _C(141), "name": "expressive",     "family": "creative", "intensity": 3, "valence": "positive"},
    "inventive":      {"emoji": "🔧", "color": _C(135), "name": "inventive",      "family": "creative", "intensity": 4, "valence": "positive"},
    "innovative":     {"emoji": "🚀", "color": _C(135), "name": "innovative",     "family": "creative", "intensity": 4, "valence": "positive"},
    "inspired":       {"emoji": "💡", "color": _C(129), "name": "inspired",       "family": "creative", "intensity": 4, "valence": "positive"},
    "creative":       {"emoji": "🎨", "color": _C(93),  "name": "creative",       "family": "creative", "intensity": 5, "valence": "positive"},
    "visionary":      {"emoji": "🔭", "color": _C(93),  "name": "visionary",      "family": "creative", "intensity": 5, "valence": "positive"},

    # ── CONFUSION (10) ───────────────────────────────────────────────────────
    "muddled":        {"emoji": "🌫️", "color": _C(253), "name": "muddled",        "family": "confusion", "intensity": 1, "valence": "negative"},
    "puzzled":        {"emoji": "❓", "color": _C(250), "name": "puzzled",        "family": "confusion", "intensity": 2, "valence": "negative"},
    "perplexed":      {"emoji": "🤔", "color": _C(248), "name": "perplexed",      "family": "confusion", "intensity": 2, "valence": "negative"},
    "bewildered":     {"emoji": "😕", "color": _C(246), "name": "bewildered",     "family": "confusion", "intensity": 3, "valence": "negative"},
    "confused":       {"emoji": "😵", "color": _C(246), "name": "confused",       "family": "confusion", "intensity": 3, "valence": "negative"},
    "scattered":      {"emoji": "📌", "color": _C(244), "name": "scattered",      "family": "confusion", "intensity": 3, "valence": "negative"},
    "disoriented":    {"emoji": "💫", "color": _C(244), "name": "disoriented",    "family": "confusion", "intensity": 4, "valence": "negative"},
    "lost":           {"emoji": "🗺️", "color": _C(242), "name": "lost",           "family": "confusion", "intensity": 4, "valence": "negative"},
    "baffled":        {"emoji": "😵‍💫", "color": _C(242), "name": "baffled",        "family": "confusion", "intensity": 5, "valence": "negative"},
    "mystified":      {"emoji": "🌀", "color": _C(240), "name": "mystified",      "family": "confusion", "intensity": 5, "valence": "negative"},

    # ── INDECISION (10) ──────────────────────────────────────────────────────
    "wavering":       {"emoji": "🌊", "color": _C(253), "name": "wavering",       "family": "indecision", "intensity": 1, "valence": "negative"},
    "undecided":      {"emoji": "🎲", "color": _C(250), "name": "undecided",      "family": "indecision", "intensity": 2, "valence": "negative"},
    "ambivalent":     {"emoji": "🤷", "color": _C(248), "name": "ambivalent",     "family": "indecision", "intensity": 2, "valence": "neutral"},
    "torn":           {"emoji": "🫀", "color": _C(246), "name": "torn",           "family": "indecision", "intensity": 3, "valence": "negative"},
    "conflicted":     {"emoji": "⚡", "color": _C(244), "name": "conflicted",     "family": "indecision", "intensity": 3, "valence": "negative"},
    "vacillating":    {"emoji": "↔️", "color": _C(244), "name": "vacillating",    "family": "indecision", "intensity": 4, "valence": "negative"},
    "at_crossroads":  {"emoji": "🛤️", "color": _C(242), "name": "at_crossroads",  "family": "indecision", "intensity": 4, "valence": "neutral"},
    "indecisive":     {"emoji": "⚖️", "color": _C(242), "name": "indecisive",     "family": "indecision", "intensity": 4, "valence": "negative"},
    "irresolute":     {"emoji": "🌀", "color": _C(238), "name": "irresolute",     "family": "indecision", "intensity": 5, "valence": "negative"},
    "paralyzed":      {"emoji": "🧊", "color": _C(238), "name": "paralyzed",      "family": "indecision", "intensity": 5, "valence": "negative"},

    # ── BOREDOM (10) ─────────────────────────────────────────────────────────
    "stagnant":       {"emoji": "🏜️", "color": _C(244), "name": "stagnant",       "family": "boredom", "intensity": 1, "valence": "negative"},
    "monotonous":     {"emoji": "📏", "color": _C(242), "name": "monotonous",     "family": "boredom", "intensity": 1, "valence": "negative"},
    "indifferent":    {"emoji": "🪨", "color": _C(242), "name": "indifferent",    "family": "boredom", "intensity": 2, "valence": "neutral"},
    "disengaged":     {"emoji": "💤", "color": _C(240), "name": "disengaged",     "family": "boredom", "intensity": 2, "valence": "negative"},
    "listless":       {"emoji": "🍃", "color": _C(240), "name": "listless",       "family": "boredom", "intensity": 3, "valence": "negative"},
    "bored":          {"emoji": "😑", "color": _C(238), "name": "bored",          "family": "boredom", "intensity": 3, "valence": "negative"},
    "unmotivated":    {"emoji": "📉", "color": _C(238), "name": "unmotivated",    "family": "boredom", "intensity": 4, "valence": "negative"},
    "lethargic":      {"emoji": "🐌", "color": _C(236), "name": "lethargic",      "family": "boredom", "intensity": 4, "valence": "negative"},
    "sluggish":       {"emoji": "🐢", "color": _C(236), "name": "sluggish",       "family": "boredom", "intensity": 4, "valence": "negative"},
    "apathetic":      {"emoji": "😶", "color": _C(234), "name": "apathetic",      "family": "boredom", "intensity": 5, "valence": "negative"},

    # ── EXHAUSTION (10) ──────────────────────────────────────────────────────
    "tired":          {"emoji": "😴", "color": _C(244), "name": "tired",          "family": "exhaustion", "intensity": 1, "valence": "negative"},
    "weary":          {"emoji": "😪", "color": _C(242), "name": "weary",          "family": "exhaustion", "intensity": 2, "valence": "negative"},
    "fatigued":       {"emoji": "🥱", "color": _C(240), "name": "fatigued",       "family": "exhaustion", "intensity": 2, "valence": "negative"},
    "worn_out":       {"emoji": "👟", "color": _C(238), "name": "worn_out",       "family": "exhaustion", "intensity": 3, "valence": "negative"},
    "drained":        {"emoji": "🪫", "color": _C(238), "name": "drained",        "family": "exhaustion", "intensity": 3, "valence": "negative"},
    "depleted":       {"emoji": "⬇️", "color": _C(236), "name": "depleted",       "family": "exhaustion", "intensity": 4, "valence": "negative"},
    "spent":          {"emoji": "💤", "color": _C(236), "name": "spent",          "family": "exhaustion", "intensity": 4, "valence": "negative"},
    "exhausted":      {"emoji": "🔋", "color": _C(234), "name": "exhausted",      "family": "exhaustion", "intensity": 4, "valence": "negative"},
    "enervated":      {"emoji": "🌫️", "color": _C(234), "name": "enervated",      "family": "exhaustion", "intensity": 5, "valence": "negative"},
    "burnt_out":      {"emoji": "🕯️", "color": _C(232), "name": "burnt_out",      "family": "exhaustion", "intensity": 5, "valence": "negative"},

    # ── OVERWHELM (10) ───────────────────────────────────────────────────────
    "pressured":      {"emoji": "⚡", "color": _C(210), "name": "pressured",      "family": "overwhelm", "intensity": 1, "valence": "negative"},
    "burdened":       {"emoji": "⛏️", "color": _C(204), "name": "burdened",       "family": "overwhelm", "intensity": 2, "valence": "negative"},
    "swamped":        {"emoji": "🌊", "color": _C(204), "name": "swamped",        "family": "overwhelm", "intensity": 2, "valence": "negative"},
    "overloaded":     {"emoji": "📦", "color": _C(197), "name": "overloaded",     "family": "overwhelm", "intensity": 3, "valence": "negative"},
    "overwhelmed":    {"emoji": "🤯", "color": _C(197), "name": "overwhelmed",    "family": "overwhelm", "intensity": 3, "valence": "negative"},
    "smothered":      {"emoji": "🧱", "color": _C(196), "name": "smothered",      "family": "overwhelm", "intensity": 4, "valence": "negative"},
    "trapped":        {"emoji": "🕸️", "color": _C(160), "name": "trapped",        "family": "overwhelm", "intensity": 4, "valence": "negative"},
    "suffocated":     {"emoji": "💨", "color": _C(160), "name": "suffocated",     "family": "overwhelm", "intensity": 5, "valence": "negative"},
    "crushed_by_weight": {"emoji": "⬇️", "color": _C(124), "name": "crushed_by_weight", "family": "overwhelm", "intensity": 5, "valence": "negative"},
    "at_limit":       {"emoji": "🚨", "color": _C(124), "name": "at_limit",       "family": "overwhelm", "intensity": 5, "valence": "negative"},

    # ── EMPOWERMENT (10) ─────────────────────────────────────────────────────
    "independent":    {"emoji": "🔓", "color": _C(157), "name": "independent",    "family": "empowerment", "intensity": 1, "valence": "positive"},
    "self_reliant":   {"emoji": "🏔️", "color": _C(121), "name": "self_reliant",   "family": "empowerment", "intensity": 2, "valence": "positive"},
    "autonomous":     {"emoji": "🤖", "color": _C(121), "name": "autonomous",     "family": "empowerment", "intensity": 2, "valence": "positive"},
    "empowered":      {"emoji": "⚡", "color": _C(82),  "name": "empowered",      "family": "empowerment", "intensity": 3, "valence": "positive"},
    "liberated":      {"emoji": "🦅", "color": _C(82),  "name": "liberated",      "family": "empowerment", "intensity": 3, "valence": "positive"},
    "sovereign":      {"emoji": "👑", "color": _C(46),  "name": "sovereign",      "family": "empowerment", "intensity": 4, "valence": "positive"},
    "untethered":     {"emoji": "🪁", "color": _C(46),  "name": "untethered",     "family": "empowerment", "intensity": 4, "valence": "positive"},
    "free":           {"emoji": "🌬️", "color": _C(48),  "name": "free",           "family": "empowerment", "intensity": 4, "valence": "positive"},
    "unrestricted":   {"emoji": "🚀", "color": _C(48),  "name": "unrestricted",   "family": "empowerment", "intensity": 5, "valence": "positive"},
    "limitless":      {"emoji": "♾️", "color": _C(40),  "name": "limitless",      "family": "empowerment", "intensity": 5, "valence": "positive"},

    # ── BELONGING (10) ───────────────────────────────────────────────────────
    "included":       {"emoji": "🤗", "color": _C(157), "name": "included",       "family": "belonging", "intensity": 1, "valence": "positive"},
    "accepted":       {"emoji": "✅", "color": _C(121), "name": "accepted",       "family": "belonging", "intensity": 2, "valence": "positive"},
    "understood":     {"emoji": "💡", "color": _C(85),  "name": "understood",     "family": "belonging", "intensity": 2, "valence": "positive"},
    "seen":           {"emoji": "👁️", "color": _C(85),  "name": "seen",           "family": "belonging", "intensity": 3, "valence": "positive"},
    "valued":         {"emoji": "💎", "color": _C(78),  "name": "valued",         "family": "belonging", "intensity": 3, "valence": "positive"},
    "respected":      {"emoji": "🫡", "color": _C(78),  "name": "respected",      "family": "belonging", "intensity": 3, "valence": "positive"},
    "admired":        {"emoji": "⭐", "color": _C(72),  "name": "admired",        "family": "belonging", "intensity": 4, "valence": "positive"},
    "celebrated":     {"emoji": "🎊", "color": _C(72),  "name": "celebrated",     "family": "belonging", "intensity": 4, "valence": "positive"},
    "cherished":      {"emoji": "💖", "color": _C(36),  "name": "cherished",      "family": "belonging", "intensity": 5, "valence": "positive"},
    "belonging":      {"emoji": "🏡", "color": _C(36),  "name": "belonging",      "family": "belonging", "intensity": 5, "valence": "positive"},

    # ── BETRAYAL (10) ────────────────────────────────────────────────────────
    "guarded":        {"emoji": "🛡️", "color": _C(138), "name": "guarded",        "family": "betrayal", "intensity": 1, "valence": "negative"},
    "distrustful":    {"emoji": "🔐", "color": _C(131), "name": "distrustful",    "family": "betrayal", "intensity": 2, "valence": "negative"},
    "closed_off":     {"emoji": "🚪", "color": _C(131), "name": "closed_off",     "family": "betrayal", "intensity": 2, "valence": "negative"},
    "cynical":        {"emoji": "🔩", "color": _C(94),  "name": "cynical",        "family": "betrayal", "intensity": 3, "valence": "negative"},
    "jaded":          {"emoji": "😒", "color": _C(94),  "name": "jaded",          "family": "betrayal", "intensity": 3, "valence": "negative"},
    "used":           {"emoji": "🪤", "color": _C(88),  "name": "used",           "family": "betrayal", "intensity": 4, "valence": "negative"},
    "manipulated":    {"emoji": "🕹️", "color": _C(88),  "name": "manipulated",    "family": "betrayal", "intensity": 4, "valence": "negative"},
    "deceived":       {"emoji": "🎭", "color": _C(52),  "name": "deceived",       "family": "betrayal", "intensity": 4, "valence": "negative"},
    "betrayed":       {"emoji": "🗡️", "color": _C(52),  "name": "betrayed",       "family": "betrayal", "intensity": 5, "valence": "negative"},
    "taken_for_granted": {"emoji": "🚮", "color": _C(52), "name": "taken_for_granted", "family": "betrayal", "intensity": 5, "valence": "negative"},

    # ── MORAL (10) ───────────────────────────────────────────────────────────
    "fair":           {"emoji": "⚖️", "color": _C(229), "name": "fair",           "family": "moral", "intensity": 1, "valence": "positive"},
    "ethical":        {"emoji": "🧭", "color": _C(229), "name": "ethical",        "family": "moral", "intensity": 2, "valence": "positive"},
    "principled":     {"emoji": "📜", "color": _C(228), "name": "principled",     "family": "moral", "intensity": 2, "valence": "positive"},
    "honorable":      {"emoji": "🎖️", "color": _C(228), "name": "honorable",      "family": "moral", "intensity": 3, "valence": "positive"},
    "dignified":      {"emoji": "👔", "color": _C(222), "name": "dignified",      "family": "moral", "intensity": 3, "valence": "positive"},
    "just":           {"emoji": "🏛️", "color": _C(222), "name": "just",           "family": "moral", "intensity": 3, "valence": "positive"},
    "virtuous":       {"emoji": "🌟", "color": _C(186), "name": "virtuous",       "family": "moral", "intensity": 4, "valence": "positive"},
    "forgiving":      {"emoji": "🕊️", "color": _C(186), "name": "forgiving",      "family": "moral", "intensity": 4, "valence": "positive"},
    "merciful":       {"emoji": "💙", "color": _C(150), "name": "merciful",       "family": "moral", "intensity": 4, "valence": "positive"},
    "righteous":      {"emoji": "⚖️", "color": _C(150), "name": "righteous",      "family": "moral", "intensity": 5, "valence": "positive"},

    # ── SHAME_DEEP (10) ──────────────────────────────────────────────────────
    "self_critical":  {"emoji": "🔍", "color": _C(244), "name": "self_critical",  "family": "shame_deep", "intensity": 1, "valence": "negative"},
    "embarrassed":    {"emoji": "😖", "color": _C(242), "name": "embarrassed",    "family": "shame_deep", "intensity": 2, "valence": "negative"},
    "ashamed":        {"emoji": "😔", "color": _C(240), "name": "ashamed",        "family": "shame_deep", "intensity": 2, "valence": "negative"},
    "guilty":         {"emoji": "😢", "color": _C(238), "name": "guilty",         "family": "shame_deep", "intensity": 3, "valence": "negative"},
    "shamed":         {"emoji": "🙈", "color": _C(238), "name": "shamed",         "family": "shame_deep", "intensity": 3, "valence": "negative"},
    "mortified":      {"emoji": "😱", "color": _C(237), "name": "mortified",      "family": "shame_deep", "intensity": 4, "valence": "negative"},
    "humiliated":     {"emoji": "😤", "color": _C(237), "name": "humiliated",     "family": "shame_deep", "intensity": 4, "valence": "negative"},
    "degraded":       {"emoji": "⬇️", "color": _C(236), "name": "degraded",       "family": "shame_deep", "intensity": 4, "valence": "negative"},
    "worthless":      {"emoji": "🗑️", "color": _C(234), "name": "worthless",      "family": "shame_deep", "intensity": 5, "valence": "negative"},
    "self_loathing":  {"emoji": "💔", "color": _C(234), "name": "self_loathing",  "family": "shame_deep", "intensity": 5, "valence": "negative"},

    # ── EXISTENTIAL (10) ─────────────────────────────────────────────────────
    "naive":          {"emoji": "🌱", "color": _C(183), "name": "naive",          "family": "existential", "intensity": 1, "valence": "neutral"},
    "innocent":       {"emoji": "🕊️", "color": _C(183), "name": "innocent",       "family": "existential", "intensity": 1, "valence": "positive"},
    "purposeful":     {"emoji": "🎯", "color": _C(105), "name": "purposeful",     "family": "existential", "intensity": 2, "valence": "positive"},
    "meaningful":     {"emoji": "✨", "color": _C(105), "name": "meaningful",     "family": "existential", "intensity": 3, "valence": "positive"},
    "wise":           {"emoji": "🦉", "color": _C(99),  "name": "wise",           "family": "existential", "intensity": 3, "valence": "positive"},
    "enlightened":    {"emoji": "💡", "color": _C(99),  "name": "enlightened",    "family": "existential", "intensity": 4, "valence": "positive"},
    "existential":    {"emoji": "🌌", "color": _C(55),  "name": "existential",    "family": "existential", "intensity": 4, "valence": "neutral"},
    "purposeless":    {"emoji": "🌫️", "color": _C(55),  "name": "purposeless",    "family": "existential", "intensity": 4, "valence": "negative"},
    "meaningless":    {"emoji": "🕳️", "color": _C(54),  "name": "meaningless",    "family": "existential", "intensity": 5, "valence": "negative"},
    "transcendent":   {"emoji": "🌠", "color": _C(54),  "name": "transcendent",   "family": "existential", "intensity": 5, "valence": "positive"},

    # ── POWER (10) ───────────────────────────────────────────────────────────
    "capable_power":  {"emoji": "💪", "color": _C(210), "name": "capable_power",  "family": "power", "intensity": 1, "valence": "positive"},
    "in_control":     {"emoji": "🎮", "color": _C(204), "name": "in_control",     "family": "power", "intensity": 2, "valence": "positive"},
    "authoritative":  {"emoji": "📢", "color": _C(197), "name": "authoritative",  "family": "power", "intensity": 3, "valence": "neutral"},
    "commanding":     {"emoji": "⚔️", "color": _C(197), "name": "commanding",     "family": "power", "intensity": 3, "valence": "neutral"},
    "dominant":       {"emoji": "🦁", "color": _C(196), "name": "dominant",       "family": "power", "intensity": 4, "valence": "neutral"},
    "powerful":       {"emoji": "⚡", "color": _C(196), "name": "powerful",       "family": "power", "intensity": 4, "valence": "positive"},
    "helpless":       {"emoji": "🙌", "color": _C(240), "name": "helpless",       "family": "power", "intensity": 3, "valence": "negative"},
    "powerless":      {"emoji": "🔋", "color": _C(238), "name": "powerless",      "family": "power", "intensity": 4, "valence": "negative"},
    "submissive":     {"emoji": "🌊", "color": _C(236), "name": "submissive",     "family": "power", "intensity": 4, "valence": "negative"},
    "controlled":     {"emoji": "🕹️", "color": _C(234), "name": "controlled",     "family": "power", "intensity": 5, "valence": "negative"},

    # ── HUMOR (10) ───────────────────────────────────────────────────────────
    "amused":         {"emoji": "😄", "color": _C(190), "name": "amused",         "family": "humor", "intensity": 1, "valence": "positive"},
    "entertained":    {"emoji": "🎭", "color": _C(190), "name": "entertained",    "family": "humor", "intensity": 2, "valence": "positive"},
    "witty":          {"emoji": "🃏", "color": _C(154), "name": "witty",          "family": "humor", "intensity": 2, "valence": "positive"},
    "playful_humor":  {"emoji": "😜", "color": _C(154), "name": "playful_humor",  "family": "humor", "intensity": 3, "valence": "positive"},
    "mischievous":    {"emoji": "😈", "color": _C(118), "name": "mischievous",    "family": "humor", "intensity": 3, "valence": "mixed"},
    "cheeky":         {"emoji": "😋", "color": _C(118), "name": "cheeky",         "family": "humor", "intensity": 3, "valence": "positive"},
    "sarcastic":      {"emoji": "🙄", "color": _C(148), "name": "sarcastic",      "family": "humor", "intensity": 4, "valence": "mixed"},
    "ironic":         {"emoji": "😏", "color": _C(148), "name": "ironic",         "family": "humor", "intensity": 4, "valence": "mixed"},
    "sardonic":       {"emoji": "😒", "color": _C(100), "name": "sardonic",       "family": "humor", "intensity": 5, "valence": "mixed"},
    "dry_humor":      {"emoji": "🎩", "color": _C(100), "name": "dry_humor",      "family": "humor", "intensity": 5, "valence": "mixed"},

    # ── CULTURAL (10) ────────────────────────────────────────────────────────
    "sonder":         {"emoji": "🌍", "color": _C(179), "name": "sonder",         "family": "cultural", "intensity": 3, "valence": "neutral"},
    "hiraeth":        {"emoji": "🏔️", "color": _C(173), "name": "hiraeth",        "family": "cultural", "intensity": 4, "valence": "mixed"},
    "fernweh":        {"emoji": "🗺️", "color": _C(172), "name": "fernweh",        "family": "cultural", "intensity": 3, "valence": "mixed"},
    "sehnsucht":      {"emoji": "🌌", "color": _C(136), "name": "sehnsucht",      "family": "cultural", "intensity": 5, "valence": "mixed"},
    "schadenfreude":  {"emoji": "😏", "color": _C(136), "name": "schadenfreude",  "family": "cultural", "intensity": 3, "valence": "mixed"},
    "saudade":        {"emoji": "🌊", "color": _C(130), "name": "saudade",        "family": "cultural", "intensity": 4, "valence": "mixed"},
    "toska":          {"emoji": "🌧️", "color": _C(130), "name": "toska",          "family": "cultural", "intensity": 4, "valence": "negative"},
    "forelsket":      {"emoji": "💘", "color": _C(172), "name": "forelsket",      "family": "cultural", "intensity": 5, "valence": "positive"},
    "mono_no_aware":  {"emoji": "🍂", "color": _C(179), "name": "mono_no_aware",  "family": "cultural", "intensity": 3, "valence": "mixed"},
    "jayus":          {"emoji": "😂", "color": _C(136), "name": "jayus",          "family": "cultural", "intensity": 2, "valence": "mixed"},

    # ── FLOW (10) ────────────────────────────────────────────────────────────
    "absorbed":       {"emoji": "🎯", "color": _C(159), "name": "absorbed",       "family": "flow", "intensity": 1, "valence": "positive"},
    "immersed":       {"emoji": "🏊", "color": _C(123), "name": "immersed",       "family": "flow", "intensity": 2, "valence": "positive"},
    "focused_flow":   {"emoji": "🔭", "color": _C(87),  "name": "focused_flow",   "family": "flow", "intensity": 2, "valence": "positive"},
    "effortless":     {"emoji": "🕊️", "color": _C(87),  "name": "effortless",     "family": "flow", "intensity": 3, "valence": "positive"},
    "flowing":        {"emoji": "🌊", "color": _C(51),  "name": "flowing",        "family": "flow", "intensity": 3, "valence": "positive"},
    "fluid":          {"emoji": "💧", "color": _C(51),  "name": "fluid",          "family": "flow", "intensity": 3, "valence": "positive"},
    "hyperfocused":   {"emoji": "🔬", "color": _C(45),  "name": "hyperfocused",   "family": "flow", "intensity": 4, "valence": "positive"},
    "in_the_zone":    {"emoji": "⚡", "color": _C(45),  "name": "in_the_zone",    "family": "flow", "intensity": 4, "valence": "positive"},
    "peak":           {"emoji": "🏔️", "color": _C(39),  "name": "peak",           "family": "flow", "intensity": 5, "valence": "positive"},
    "transcending":   {"emoji": "🚀", "color": _C(39),  "name": "transcending",   "family": "flow", "intensity": 5, "valence": "positive"},

    # ── SPIRITUAL (10) ───────────────────────────────────────────────────────
    "prayerful":      {"emoji": "🙏", "color": _C(189), "name": "prayerful",      "family": "spiritual", "intensity": 1, "valence": "positive"},
    "reverent":       {"emoji": "🕯️", "color": _C(183), "name": "reverent",       "family": "spiritual", "intensity": 2, "valence": "positive"},
    "devotional":     {"emoji": "🫶", "color": _C(141), "name": "devotional",     "family": "spiritual", "intensity": 2, "valence": "positive"},
    "zenlike":        {"emoji": "☯️", "color": _C(141), "name": "zenlike",        "family": "spiritual", "intensity": 3, "valence": "positive"},
    "meditative":     {"emoji": "🧘", "color": _C(135), "name": "meditative",     "family": "spiritual", "intensity": 3, "valence": "positive"},
    "sacred":         {"emoji": "⛩️", "color": _C(99),  "name": "sacred",         "family": "spiritual", "intensity": 4, "valence": "positive"},
    "mystical":       {"emoji": "🔮", "color": _C(99),  "name": "mystical",       "family": "spiritual", "intensity": 4, "valence": "positive"},
    "awakened":       {"emoji": "🌅", "color": _C(93),  "name": "awakened",       "family": "spiritual", "intensity": 5, "valence": "positive"},
    "cosmic":         {"emoji": "🌠", "color": _C(93),  "name": "cosmic",         "family": "spiritual", "intensity": 5, "valence": "positive"},
    "numinous":       {"emoji": "✨", "color": _C(57),  "name": "numinous",       "family": "spiritual", "intensity": 5, "valence": "positive"},

    # ── SOCIAL_AWKWARD (10) ──────────────────────────────────────────────────
    "people_pleasing": {"emoji": "😅", "color": _C(223), "name": "people_pleasing", "family": "social_awkward", "intensity": 1, "valence": "negative"},
    "oversharing":    {"emoji": "🗣️", "color": _C(223), "name": "oversharing",    "family": "social_awkward", "intensity": 2, "valence": "negative"},
    "fawning":        {"emoji": "🐕", "color": _C(217), "name": "fawning",        "family": "social_awkward", "intensity": 2, "valence": "negative"},
    "awkward":        {"emoji": "😬", "color": _C(217), "name": "awkward",        "family": "social_awkward", "intensity": 3, "valence": "negative"},
    "socially_anxious": {"emoji": "😰", "color": _C(216), "name": "socially_anxious", "family": "social_awkward", "intensity": 3, "valence": "negative"},
    "clingy":         {"emoji": "🔗", "color": _C(216), "name": "clingy",         "family": "social_awkward", "intensity": 3, "valence": "negative"},
    "needy":          {"emoji": "🙏", "color": _C(210), "name": "needy",          "family": "social_awkward", "intensity": 4, "valence": "negative"},
    "cringe":         {"emoji": "😣", "color": _C(210), "name": "cringe",         "family": "social_awkward", "intensity": 4, "valence": "negative"},
    "self_sabotaging": {"emoji": "💣", "color": _C(209), "name": "self_sabotaging", "family": "social_awkward", "intensity": 5, "valence": "negative"},
    "secondhand_embarrassed": {"emoji": "😖", "color": _C(209), "name": "secondhand_embarrassed", "family": "social_awkward", "intensity": 5, "valence": "negative"},

    # ── RESILIENCE (10) ──────────────────────────────────────────────────────
    "recovering":     {"emoji": "🔄", "color": _C(157), "name": "recovering",     "family": "resilience", "intensity": 1, "valence": "positive"},
    "adapting":       {"emoji": "🦎", "color": _C(121), "name": "adapting",       "family": "resilience", "intensity": 2, "valence": "positive"},
    "learning":       {"emoji": "📚", "color": _C(85),  "name": "learning",       "family": "resilience", "intensity": 2, "valence": "positive"},
    "healing":        {"emoji": "💚", "color": _C(85),  "name": "healing",        "family": "resilience", "intensity": 3, "valence": "positive"},
    "growing":        {"emoji": "📈", "color": _C(71),  "name": "growing",        "family": "resilience", "intensity": 3, "valence": "positive"},
    "resilient":      {"emoji": "🌱", "color": _C(71),  "name": "resilient",      "family": "resilience", "intensity": 3, "valence": "positive"},
    "rebounding":     {"emoji": "🏀", "color": _C(65),  "name": "rebounding",     "family": "resilience", "intensity": 4, "valence": "positive"},
    "renewed":        {"emoji": "🌿", "color": _C(65),  "name": "renewed",        "family": "resilience", "intensity": 4, "valence": "positive"},
    "transforming":   {"emoji": "🦋", "color": _C(35),  "name": "transforming",   "family": "resilience", "intensity": 5, "valence": "positive"},
    "evolving":       {"emoji": "🔄", "color": _C(35),  "name": "evolving",       "family": "resilience", "intensity": 5, "valence": "positive"},

    # ── COMPLEXITY (10) ──────────────────────────────────────────────────────
    "nuanced":        {"emoji": "🎨", "color": _C(189), "name": "nuanced",        "family": "complexity", "intensity": 1, "valence": "neutral"},
    "layered":        {"emoji": "📚", "color": _C(183), "name": "layered",        "family": "complexity", "intensity": 2, "valence": "neutral"},
    "multifaceted":   {"emoji": "💎", "color": _C(177), "name": "multifaceted",   "family": "complexity", "intensity": 2, "valence": "neutral"},
    "in_between":     {"emoji": "🌗", "color": _C(147), "name": "in_between",     "family": "complexity", "intensity": 3, "valence": "neutral"},
    "ambiguous":      {"emoji": "🌀", "color": _C(147), "name": "ambiguous",      "family": "complexity", "intensity": 3, "valence": "neutral"},
    "oscillating":    {"emoji": "↕️", "color": _C(141), "name": "oscillating",    "family": "complexity", "intensity": 3, "valence": "neutral"},
    "contradictory":  {"emoji": "↔️", "color": _C(135), "name": "contradictory",  "family": "complexity", "intensity": 4, "valence": "mixed"},
    "intricate":      {"emoji": "🕸️", "color": _C(135), "name": "intricate",      "family": "complexity", "intensity": 4, "valence": "neutral"},
    "paradoxical":    {"emoji": "∞",  "color": _C(141), "name": "paradoxical",    "family": "complexity", "intensity": 5, "valence": "mixed"},
    "complicated":    {"emoji": "🔀", "color": _C(141), "name": "complicated",    "family": "complexity", "intensity": 5, "valence": "negative"},

    # ── NUMB (10) ────────────────────────────────────────────────────────────
    "flat":           {"emoji": "📏", "color": _C(240), "name": "flat",           "family": "numb", "intensity": 1, "valence": "neutral"},
    "going_through_motions": {"emoji": "🤖", "color": _C(238), "name": "going_through_motions", "family": "numb", "intensity": 1, "valence": "neutral"},
    "detached":       {"emoji": "🔌", "color": _C(238), "name": "detached",       "family": "numb", "intensity": 2, "valence": "neutral"},
    "disconnected":   {"emoji": "📡", "color": _C(236), "name": "disconnected",   "family": "numb", "intensity": 2, "valence": "neutral"},
    "anesthetized":   {"emoji": "💊", "color": _C(236), "name": "anesthetized",   "family": "numb", "intensity": 3, "valence": "neutral"},
    "hollow":         {"emoji": "🕳️", "color": _C(234), "name": "hollow",         "family": "numb", "intensity": 3, "valence": "negative"},
    "dissociated":    {"emoji": "👁️", "color": _C(234), "name": "dissociated",    "family": "numb", "intensity": 4, "valence": "negative"},
    "empty":          {"emoji": "⚫", "color": _C(234), "name": "empty",          "family": "numb", "intensity": 4, "valence": "negative"},
    "deadened":       {"emoji": "💀", "color": _C(232), "name": "deadened",       "family": "numb", "intensity": 5, "valence": "negative"},
    "numb":           {"emoji": "🧊", "color": _C(232), "name": "numb",           "family": "numb", "intensity": 5, "valence": "negative"},

    # ── HOPE (10) ────────────────────────────────────────────────────────────
    "positive":       {"emoji": "➕", "color": _C(229), "name": "positive",       "family": "hope", "intensity": 1, "valence": "positive"},
    "optimistic":     {"emoji": "☀️", "color": _C(229), "name": "optimistic",     "family": "hope", "intensity": 2, "valence": "positive"},
    "uplifted":       {"emoji": "🎈", "color": _C(222), "name": "uplifted",       "family": "hope", "intensity": 2, "valence": "positive"},
    "trusting":       {"emoji": "🤝", "color": _C(222), "name": "trusting",       "family": "hope", "intensity": 3, "valence": "positive"},
    "faithful":       {"emoji": "⭐", "color": _C(221), "name": "faithful",       "family": "hope", "intensity": 3, "valence": "positive"},
    "believing":      {"emoji": "🙏", "color": _C(221), "name": "believing",      "family": "hope", "intensity": 3, "valence": "positive"},
    "aspiring":       {"emoji": "🌅", "color": _C(185), "name": "aspiring",       "family": "hope", "intensity": 4, "valence": "positive"},
    "hopeful_bright": {"emoji": "🌈", "color": _C(185), "name": "hopeful_bright", "family": "hope", "intensity": 4, "valence": "positive"},
    "expectant_good": {"emoji": "🌱", "color": _C(149), "name": "expectant_good", "family": "hope", "intensity": 5, "valence": "positive"},
    "visionary_hope": {"emoji": "🔭", "color": _C(149), "name": "visionary_hope", "family": "hope", "intensity": 5, "valence": "positive"},
}

EMOTION_NAMES = list(EMOTIONS.keys())
RESET = "\033[0m"
BOLD  = "\033[1m"
DIM   = "\033[2m"
